@@ -647,14 +647,14 @@ class CodeGenerator(object):
         if self.flask:
             # Add Flask-SQLAlchemy support
             self.collector.add_literal_import('flask_sqlalchemy', 'SQLAlchemy')
-            parent_name = 'db.Model'
+            parent_name = 'BaseModel'
 
             for model in classes.values():
                 if model.parent_name == 'Base':
                     model.parent_name = parent_name
-        else:
-            self.collector.add_literal_import('sqlalchemy.ext.declarative', 'declarative_base')
-            self.collector.add_literal_import('sqlalchemy', 'MetaData')
+        # else:
+        #     self.collector.add_literal_import('sqlalchemy.ext.declarative', 'declarative_base')
+        #     self.collector.add_literal_import('sqlalchemy', 'MetaData')
 
     def render(self, outdir):
         if not os.path.exists(outdir):
@@ -666,14 +666,64 @@ class CodeGenerator(object):
                 s = """\
 #!/usr/bin/env python
 # -*- coding:utf-8 -*-
+
+from sqlalchemy import inspect
+from sqlalchemy.engine import Row
 from flask_sqlalchemy import SQLAlchemy
 
 db = SQLAlchemy()
-            """
+
+
+class BaseModel(db.Model):
+    __abstract__ = True
+
+    @classmethod
+    def to_dict(cls, models):
+        # 查询结果为空
+        if len(models) == 0:
+            return []
+        # 查询结果不包含所有字段的情况
+        if isinstance(models[0], Row):
+            return [row._asdict() for row in models]
+        # 查询结果包含所有字段的情况
+        else:
+            return [cls._asdict(model) for model in models]
+
+    def _asdict(self):
+        return {c.key: getattr(self, c.key)
+                for c in inspect(self).mapper.column_attrs}
+"""
             else:
                 s = """\
 #!/usr/bin/env python
-# -*- coding:utf-8 -*-"""
+# -*- coding:utf-8 -*-
+
+from sqlalchemy import inspect
+from sqlalchemy.engine import Row
+from sqlalchemy.ext.declarative import declarative_base
+
+DeclarativeBase = declarative_base()
+
+
+class Base(DeclarativeBase):
+    __abstract__ = True
+
+    @classmethod
+    def to_dict(cls, models):
+        # 查询结果为空
+        if len(models) == 0:
+            return []
+        # 查询结果不包含所有字段的情况
+        if isinstance(models[0], Row):
+            return [row._asdict() for row in models]
+        # 查询结果包含所有字段的情况
+        else:
+            return [cls._asdict(model) for model in models]
+
+    def _asdict(self):
+        return {c.key: getattr(self, c.key)
+                for c in inspect(self).mapper.column_attrs}
+"""
             outfile.write(s)
 
         for model in self.models:
@@ -681,17 +731,17 @@ db = SQLAlchemy()
             with open(outfilename, "w", encoding="utf-8") as outfile:
                 print(self.header, file=outfile)
                 if self.flask:
-                    print('from . import db', file=outfile)
+                    print('from . import db, BaseModel', file=outfile)
                 else:
                     # Render the collected imports
                     print(self.collector.render() + '\n\n', file=outfile)
 
                     if any(isinstance(model, ModelClass) for model in self.models):
-                        print('Base = declarative_base()\nmetadata = Base.metadata', file=outfile)
+                        print('from . import Base', file=outfile)
                     else:
                         print('metadata = MetaData()', file=outfile)
 
-                print('\n\n', file=outfile)
+                print('\n', file=outfile)
                 print(model.render().rstrip('\n'), file=outfile)
 
                 if self.footer:
